==> c8y_client-0.0.1.tar.gz: lib/src/inventory/implementations/managed_object_collection_impl.dart <==

import 'package:c8y_client/src/core/implementations/paged_resource_collention.dart';
import 'package:c8y_client/src/inventory/implementations/paged_managed_object_collection_representation.dart';
import 'package:c8y_client/src/inventory/model/Managed_object_collection_representation.dart';
import 'package:c8y_client/src/inventory/model/managed_object_collention.dart';
import 'package:c8y_client/src/rest/representation/cumulocity_media_type.dart';
import 'package:c8y_client/src/rest/representation/inventory/inventory_media_type.dart';
import 'package:c8y_client/src/rest/representation/inventory/managed_object_representation.dart';
import 'package:c8y_client/src/sdk/client/rest_connector.dart';

class ManagedObjectCollectionImpl extends PagedResourceCollectionImpl<
        ManagedObjectRepresentation,
        ManagedObjectCollectionRepresentation,
        PagedManagedObjectCollectionRepresentation>
    implements ManagedObjectCollection {
  ManagedObjectCollectionImpl(
      RestConnector restConnector, String url, int pageSize)
      : super(restConnector, url, pageSize);

  @override
  CumulocityMediaType MediaType() {
    return InventoryMediaType.MANAGED_OBJECT_COLLECTION;
  }

  @override
  PagedManagedObjectCollectionRepresentation wrap(
      ManagedObjectCollectionRepresentation collection) {
    return PagedManagedObjectCollectionRepresentation(collection, this);
  }

  @override
  ManagedObjectCollectionRepresentation parser(Map<String, Object> json) {
    return ManagedObjectCollectionRepresentation.fromJson(json);
  }

}

==> c8y_client-0.0.2.tar.gz: lib/src/inventory/implementations/managed_object_collection_impl.dart <==
import 'package:c8y_client/src/core/implementations/paged_resource_collention.dart';
import 'package:c8y_client/src/inventory/implementations/paged_managed_object_collection_representation.dart';
import 'package:c8y_client/src/inventory/model/Managed_object_collection_representation.dart';
import 'package:c8y_client/src/inventory/model/managed_object_collention.dart';
import 'package:c8y_client/src/core/model/cumulocity_media_type.dart';
import 'package:c8y_client/src/inventory/model/inventory_media_type.dart';
import 'package:c8y_client/src/inventory/model/managed_object_representation.dart';
import 'package:c8y_client/src/sdk/client/rest_connector.dart';

class ManagedObjectCollectionImpl extends PagedResourceCollectionImpl<
        ManagedObjectRepresentation,
        ManagedObjectCollectionRepresentation,
        PagedManagedObjectCollectionRepresentation>
    implements ManagedObjectCollection {
  ManagedObjectCollectionImpl(
      RestConnector restConnector, String url, int pageSize)
      : super(restConnector, url, pageSize);


  @override
  PagedManagedObjectCollectionRepresentation wrap(
      ManagedObjectCollectionRepresentation collection) {
    return PagedManagedObjectCollectionRepresentation(collection, this);
  }

  @override
  ManagedObjectCollectionRepresentation parser(Map<String, Object> json) {
    return ManagedObjectCollectionRepresentation.fromJson(json);
  }

  @override
  CumulocityMediaType mediaType() {
    return InventoryMediaType.MANAGED_OBJECT_COLLECTION;
  }
}
